Statements that invoke special data processing or calculations to return a CSS value for a CSS property.
Resources
Re-exports
pub use var::*;
Modules
- var
- Cascading variables as a new primitive value type that is accepted by all CSS properties, and custom properties for defining them.